# Forex API

###### A small library to fetch forex data


## Installation

`pip install Forex-API-hw2`


## Get Started

##### How to use
```
from hw1_forexAPI_library import getApiKey

getApiKey()
```